@@ -213,6 +213,13 @@ sub upload {
 
 ################################################################################
 
+sub uri {
+	my $self = shift;
+	return $self -> {Q} -> url (-path_info => 1);
+}
+
+################################################################################
+
 package Apache::Constants;
 
 sub OK () {
